@@ -34,21 +34,21 @@
 #include "orbitcpp_types.h"
 #include "orbitcpp_tools.h"
 
-#include "orbitcpp/orb-cpp/smartpointers/arrayfixed_forany.h"
-#include "orbitcpp/orb-cpp/smartpointers/arrayfixed_var.h"
-#include "orbitcpp/orb-cpp/smartpointers/arrayvariable_forany.h"
-#include "orbitcpp/orb-cpp/smartpointers/arrayvariable_out.h"
-#include "orbitcpp/orb-cpp/smartpointers/arrayvariable_var.h"
-#include "orbitcpp/orb-cpp/smartpointers/data_out.h"
-#include "orbitcpp/orb-cpp/smartpointers/data_var.h"
-#include "orbitcpp/orb-cpp/smartpointers/datavar_out.h"
-#include "orbitcpp/orb-cpp/smartpointers/datavar_var.h"
-#include "orbitcpp/orb-cpp/smartpointers/objectptr_out.h"
-#include "orbitcpp/orb-cpp/smartpointers/objectptr_var.h"
-#include "orbitcpp/orb-cpp/smartpointers/sequence_out.h"
-#include "orbitcpp/orb-cpp/smartpointers/sequence_var.h"
-#include "orbitcpp/orb-cpp/smartpointers/string_out.h"
-#include "orbitcpp/orb-cpp/smartpointers/string_out.h"
+#include "smartpointers/arrayfixed_forany.h"
+#include "smartpointers/arrayfixed_var.h"
+#include "smartpointers/arrayvariable_forany.h"
+#include "smartpointers/arrayvariable_out.h"
+#include "smartpointers/arrayvariable_var.h"
+#include "smartpointers/data_out.h"
+#include "smartpointers/data_var.h"
+#include "smartpointers/datavar_out.h"
+#include "smartpointers/datavar_var.h"
+#include "smartpointers/objectptr_out.h"
+#include "smartpointers/objectptr_var.h"
+#include "smartpointers/sequence_out.h"
+#include "smartpointers/sequence_var.h"
+#include "smartpointers/string_out.h"
+#include "smartpointers/string_out.h"
 
 namespace CORBA {
 	class Object;
